//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[hasKazoeYakuman](has-kazoe-yakuman.md)

# hasKazoeYakuman

[common]\
val [hasKazoeYakuman](has-kazoe-yakuman.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否有累计役满（false则除役满牌型外最高三倍满）
